import { For, createSignal, onMount } from "solid-js";

interface Page {
  path: string,
  name: string,
}

const pages: Page[] = [
  { path: "/", name: "about" },
  { path: "/writing", name: "writing" },
  { path: "/music", name: "music" },
]

const inactiveClasses = "text-xl text-fg_light transition-all duration-300 hover:scale-[110%] hover:text-foreground";
const activeClasses = "font-bold !text-foreground";


const Nav = () => {
  const [page, setPage] = createSignal<string>("");
  onMount(() => {
    if (page() != window.location.pathname) {
      setPage(window.location.pathname);
    }
  })
  return (
    <div class="flex justify-around my-10">
      <div>
        <h1 class="text-4xl md:text-6xl font-bold font-display text-center">J. Hunter DeLoche.</h1>
        <nav class="pt-4">
          <div class="flex flex-row items-center justify-around mx-auto">
            <For each={pages}>{
              (ppage, _) =>
                <a class={
                  (ppage.path == page() || ppage.path + "/" == page()) ?
                    inactiveClasses + " " + activeClasses :
                    inactiveClasses
                }
                  href={ppage.path}
                  onClick={() => setPage(ppage.path)}
                >
                  {ppage.name}
                </a>
            }</For>
          </div>
        </nav>
      </div>
    </div>
  );
};

export default Nav;
